from typing import List

# See: https://www.mediawiki.org/wiki/User:TJones_(WMF)/Notes/Spaceless_Writing_Systems_and_Wiki-Projects
NON_WHITESPACE_LANGUAGES: List[str] = [
    "bo",  # space-less
    "dz",
    "gan",
    "ja",
    "km",
    "lo",
    "my",
    "th",
    "wuu",
    "zh",
    "zh-classical",
    "zh-yue",
    "bug",  # mixed space/spaceless. could also add: 'jv', 'zh-min-nan'
    "cdo",
    "cr",
    "hak",
    "vi",  # spaces but between syllables and not words
]

WIKIPEDIA_LANGUAGES: List[str] = [
    "ab",
    "ace",
    "ady",
    "af",
    "ak",
    "als",
    "alt",
    "am",
    "ami",
    "an",
    "ang",
    "ar",
    "arc",
    "ary",
    "arz",
    "as",
    "ast",
    "atj",
    "av",
    "avk",
    "awa",
    "ay",
    "az",
    "azb",
    "ba",
    "ban",
    "bar",
    "bat-smg",
    "bcl",
    "be",
    "be-x-old",
    "bg",
    "bh",
    "bi",
    "bjn",
    "blk",
    "bm",
    "bn",
    "bo",
    "bpy",
    "br",
    "bs",
    "bug",
    "bxr",
    "ca",
    "cbk-zam",
    "cdo",
    "ce",
    "ceb",
    "ch",
    "chr",
    "chy",
    "ckb",
    "co",
    "cr",
    "crh",
    "cs",
    "csb",
    "cu",
    "cv",
    "cy",
    "da",
    "dag",
    "de",
    "din",
    "diq",
    "dsb",
    "dty",
    "dv",
    "dz",
    "ee",
    "el",
    "eml",
    "en",
    "eo",
    "es",
    "et",
    "eu",
    "ext",
    "fa",
    "ff",
    "fi",
    "fiu-vro",
    "fj",
    "fo",
    "fr",
    "frp",
    "frr",
    "fur",
    "fy",
    "ga",
    "gag",
    "gan",
    "gcr",
    "gd",
    "gl",
    "glk",
    "gn",
    "gom",
    "gor",
    "got",
    "gu",
    "guw",
    "gv",
    "ha",
    "hak",
    "haw",
    "he",
    "hi",
    "hif",
    "hr",
    "hsb",
    "ht",
    "hu",
    "hy",
    "hyw",
    "ia",
    "id",
    "ie",
    "ig",
    "ik",
    "ilo",
    "inh",
    "io",
    "is",
    "it",
    "iu",
    "ja",
    "jam",
    "jbo",
    "jv",
    "ka",
    "kaa",
    "kab",
    "kbd",
    "kbp",
    "kcg",
    "kg",
    "ki",
    "kk",
    "kl",
    "km",
    "kn",
    "ko",
    "koi",
    "krc",
    "ks",
    "ksh",
    "ku",
    "kv",
    "kw",
    "ky",
    "la",
    "lad",
    "lb",
    "lbe",
    "lez",
    "lfn",
    "lg",
    "li",
    "lij",
    "lld",
    "lmo",
    "ln",
    "lo",
    "lt",
    "ltg",
    "lv",
    "mad",
    "mai",
    "map-bms",
    "mdf",
    "mg",
    "mhr",
    "mi",
    "min",
    "mk",
    "ml",
    "mn",
    "mni",
    "mnw",
    "mr",
    "mrj",
    "ms",
    "mt",
    "mwl",
    "my",
    "myv",
    "mzn",
    "na",
    "nah",
    "nap",
    "nds",
    "nds-nl",
    "ne",
    "new",
    "nia",
    "nl",
    "nn",
    "no",
    "nov",
    "nqo",
    "nrm",
    "nso",
    "nv",
    "ny",
    "oc",
    "olo",
    "om",
    "or",
    "os",
    "pa",
    "pag",
    "pam",
    "pap",
    "pcd",
    "pcm",
    "pdc",
    "pfl",
    "pi",
    "pih",
    "pl",
    "pms",
    "pnb",
    "pnt",
    "ps",
    "pt",
    "pwn",
    "qu",
    "rm",
    "rmy",
    "rn",
    "ro",
    "roa-rup",
    "roa-tara",
    "ru",
    "rue",
    "rw",
    "sa",
    "sah",
    "sat",
    "sc",
    "scn",
    "sco",
    "sd",
    "se",
    "sg",
    "sh",
    "shi",
    "shn",
    "si",
    "simple",
    "sk",
    "skr",
    "sl",
    "sm",
    "smn",
    "sn",
    "so",
    "sq",
    "sr",
    "srn",
    "ss",
    "st",
    "stq",
    "su",
    "sv",
    "sw",
    "szl",
    "szy",
    "ta",
    "tay",
    "tcy",
    "te",
    "tet",
    "tg",
    "th",
    "ti",
    "tk",
    "tl",
    "tn",
    "to",
    "tpi",
    "tr",
    "trv",
    "ts",
    "tt",
    "tum",
    "tw",
    "ty",
    "tyv",
    "udm",
    "ug",
    "uk",
    "ur",
    "uz",
    "ve",
    "vec",
    "vep",
    "vi",
    "vls",
    "vo",
    "wa",
    "war",
    "wo",
    "wuu",
    "xal",
    "xh",
    "xmf",
    "yi",
    "yo",
    "za",
    "zea",
    "zh",
    "zh-classical",
    "zh-min-nan",
    "zh-yue",
    "zu",
]



from typing import List

import requests


def get_wiki_sites(project: str = "wiki") -> List[str]:
    """Get all language codes for a given Wikimedia project.

    Valid project codes:
    * wiki = Wikipedia
    * wiktionary = Wiktionary
    * wikibooks = Wikibooks
    * wikinews = Wikinews
    * wikiquote = Wikiquote
    * wikisource = Wikisource
    * wikiversity = Wikiversity
    * wikivoyage = Wikivoyage
    """
    session = requests.Session()
    base_url = "https://meta.wikimedia.org/w/api.php"
    params = {
        "action": "sitematrix",
        "smlangprop": "|".join(["code", "site"]),
        "smsiteprop": "|".join(["code"]),
        "format": "json",
        "formatversion": "2",
    }
    result = session.get(url=base_url, params=params).json()

    wiki_languages = set()
    if "sitematrix" in result:
        for lang in result["sitematrix"]:
            try:
                int(lang)  # weirdly, wikis are keyed as numbers in the results
                for wiki in result["sitematrix"][lang].get("site", []):
                    if "closed" not in wiki and wiki["code"] == project:
                        wiki_languages.add(result["sitematrix"][lang]["code"])
                        break
            except ValueError:  # skip count metadata and special wikis like Commons, Affiliates, etc.
                continue
    return sorted(wiki_languages)


if __name__ == "__main__":
    print(get_wiki_sites("wiki"))  # Wikipedia languages
